package factory;

import currency.*;

// concrete Factory; creates different types of concrete CurrencyMakers
public class CanadianMoneyMint implements MoneyMint {
	
	// the (parameterized) Factory Method
	// @param type the type of CurrencyMaker to create
	// @return a CurrencyMaker instance, or null if an illegal type is specified
	public CurrencyMaker createCurrencyMaker(String type) {
		CurrencyMaker cm = null;
		switch( type ) {
		case "CANADA_COIN":
			cm = new CanadianDollarCoinMaker();
			break;

		case "CANADA_BILL":
			cm = new CanadianDollarBillMaker();
			break;

		// there could be many more CurrencyMakers created here....
			
		default:
			return null; // we don't know what kind of CurrencyMaker to make
		}

		return cm;
	}
}