package factory;

import currency.*;

// concrete Factory; creates different types of concrete CurrencyMakers
public class USMoneyMint implements MoneyMint {
	
	// the (parameterized) Factory Method
	// @param type the type of CurrencyMaker to create
	// @return a CurrencyMaker instance, or null if an illegal type is specified
	public CurrencyMaker createCurrencyMaker(String type) {
		CurrencyMaker cm = null;
		switch( type ) {
		case "DOLLAR_COIN":
			cm = new DollarCoinMaker();
			break;

		case "DOLLAR_BILL":
			cm = new DollarBillMaker();
			break;

		// there could be many more CurrencyMakers created here....
			
		default:
			return null; // we don't know what kind of CurrencyMaker to make
		}

		return cm;
	}
}